import { useFoundationModel } from '@foundationui/react-hooks';
import { ICompletionResponse } from './protocol';
/**
 * Responsible for fetching completions from a model and adding them to the input.
 * Each `<SmartInput />` component rendered to the DOM will have its own instance of this class as state.
 */
export declare class SmartInputFetcher {
    addCompletion: (text: string, completion: ICompletionResponse, force?: boolean) => void;
    receiveCompletion: (text: string, completion: ICompletionResponse, force?: boolean) => void;
    foundationModel: ReturnType<typeof useFoundationModel>;
    model: string;
    /**
     * sequenceId is used to ensure that we don't add completions from a previous fetch,
     * we increment it each time we request to fetch a new completion because the user input has changed
     */
    sequenceId: number;
    /**
     * sessionId is used to track this particular instantiation of the `<SmartInput />` component
     */
    sessionId: string;
    /**
     * completionCache is used to cache the completions that we've already fetched from the model
     */
    completionCache: Record<string, ICompletionResponse | null>;
    /**
     * currentCompletion tracks the latest text that was sent to the model for fetching completions, and the
     * completion that was returned (if any ~ we may still be waiting for it)
     */
    currentCompletion: {
        sequenceId: number;
        text: string;
        completion?: string | null;
    } | null;
    blurred: boolean;
    ignoreNextFetch: boolean;
    eventsByModel: Record<string, {
        model: string;
        session: string;
        input: string;
        user?: string;
        context?: string;
    }>;
    constructor(addCompletion: (text: string, completion: ICompletionResponse, force?: boolean) => void, receiveCompletion: (text: string, completion: ICompletionResponse, force?: boolean) => void, foundationModel: ReturnType<typeof useFoundationModel>, model: string);
    fetchCompletion: {
        (...args: any[]): any;
        cancel: () => void;
        flush: () => any;
    };
    updateCompletion(completionSid: string, arg: {
        seen?: boolean;
        accepted?: boolean;
    }): void;
    addEvent: {
        (...args: any[]): any;
        cancel: () => void;
        flush: () => any;
    };
}
